/*
 *  Kylin Box security
 *
 *  This file contains apis for Kylin Box security libraries
 *
 *  Authors:  songchuanfei <songchuanfei@kylinos.cn>
 *  Authors:  huanfuxi <huanfuxi@kylinos.cn>
 *  Authors:  mengyuan <mengyuan@kylinos.cn>
 *
 *  Copyright (C) 2017,Tianjin KYLIN Information Technology Co., Ltd.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */
#ifndef BOX_LIB_INCLUDE_H
#define BOX_LIB_INCLUDE_H



#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>
#include <attr/xattr.h>
#include <sys/types.h>
#include <sys/queue.h>
#include <ftw.h>

#include <box.h>

#define ID_TYPE_USER    0x1
#define ID_TYPE_GROUP   0x2

#define box_error(...) fprintf(stderr,  __VA_ARGS__)
#define box_warning(...) fprintf(stderr, "Warning: "  __VA_ARGS__)

#define MODE_READONLY 	0x5
#define MODE_READWRITE	0x7

typedef struct{
	int id_type;
	id_t id_val;
	mode_t perm;
}ShareEntry;

struct Entry{
    ShareEntry data;
    TAILQ_ENTRY(Entry) hooks;
};

TAILQ_HEAD(EntryList, Entry);

#ifdef __cplusplus
extern "C"{
#endif

typedef void(*PrintFunc)(const char *path, void *user_data);



int box_is_enabled(void);
int box_create_dir( const char *box_path );
int box_delete_dir( const char *box_path );
int box_check_dir(  const char *box_path, int check_uid );

int box_dir_add_share( const char *box_path, mode_t perm , id_t id, int id_type );
int box_dir_remove_share( const char *box_path, id_t id, int id_type);
int box_dir_clear_share( const char *box_path);

struct EntryList *box_dir_get_share_list( const char *box_path );
void box_dir_free_share_list(struct EntryList *entries);

char *make_box_path( const char *box_name );

int box_get_data( const char *box_path, struct box_struct *box_data );

#define foreach_entry(entry, list) \
    for( struct Entry *entry=list->tqh_first; entry; entry=entry->hooks.tqe_next)



#ifdef __cplusplus
}
#endif


#endif
